==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTHttp2Protocol.md <==
# AwsIoTHttp2Protocol


```text
aws-20210730/Resource/LoT/AwsIoTHttp2Protocol
```

```text
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')
```



| Illustration | AwsIoTHttp2Protocol | AwsIoTHttp2ProtocolCard | AwsIoTHttp2ProtocolGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTHttp2Protocol.png) | ![illustration for AwsIoTHttp2Protocol](../../../aws-20210730/Resource/LoT/AwsIoTHttp2Protocol.Local.png) | ![illustration for AwsIoTHttp2ProtocolCard](../../../aws-20210730/Resource/LoT/AwsIoTHttp2ProtocolCard.Local.png) | ![illustration for AwsIoTHttp2ProtocolGroup](../../../aws-20210730/Resource/LoT/AwsIoTHttp2ProtocolGroup.Local.png) |




## AwsIoTHttp2Protocol

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2Protocol
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2Protocol('AwsIoTHttp2Protocol', 'Aws Io T Http2 Protocol', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2Protocol
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2Protocol('AwsIoTHttp2Protocol', 'Aws Io T Http2 Protocol', 'an optional tech label')
@enduml
```

## AwsIoTHttp2ProtocolCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2ProtocolCard
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2ProtocolCard('AwsIoTHttp2ProtocolCard', 'Aws Io T Http2 Protocol Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2ProtocolCard
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2ProtocolCard('AwsIoTHttp2ProtocolCard', 'Aws Io T Http2 Protocol Card', 'an optional description')
@enduml
```

## AwsIoTHttp2ProtocolGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2ProtocolGroup
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2ProtocolGroup('AwsIoTHttp2ProtocolGroup', 'Aws Io T Http2 Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2ProtocolGroup
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2ProtocolGroup('AwsIoTHttp2ProtocolGroup', 'Aws Io T Http2 Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/LoT/AwsIoTHttp2Protocol.md <==
# AwsIoTHttp2Protocol


```text
aws-20210730/Resource/LoT/AwsIoTHttp2Protocol
```

```text
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')
```



| Illustration | AwsIoTHttp2Protocol | AwsIoTHttp2ProtocolCard | AwsIoTHttp2ProtocolGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/LoT/AwsIoTHttp2Protocol.png) | ![illustration for AwsIoTHttp2Protocol](../../../aws-20210730/Resource/LoT/AwsIoTHttp2Protocol.Local.png) | ![illustration for AwsIoTHttp2ProtocolCard](../../../aws-20210730/Resource/LoT/AwsIoTHttp2ProtocolCard.Local.png) | ![illustration for AwsIoTHttp2ProtocolGroup](../../../aws-20210730/Resource/LoT/AwsIoTHttp2ProtocolGroup.Local.png) |




## AwsIoTHttp2Protocol

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2Protocol
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2Protocol('AwsIoTHttp2Protocol', 'Aws Io T Http2 Protocol', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2Protocol
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2Protocol('AwsIoTHttp2Protocol', 'Aws Io T Http2 Protocol', 'an optional tech label')
@enduml
```

## AwsIoTHttp2ProtocolCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2ProtocolCard
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2ProtocolCard('AwsIoTHttp2ProtocolCard', 'Aws Io T Http2 Protocol Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2ProtocolCard
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2ProtocolCard('AwsIoTHttp2ProtocolCard', 'Aws Io T Http2 Protocol Card', 'an optional description')
@enduml
```

## AwsIoTHttp2ProtocolGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2ProtocolGroup
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2ProtocolGroup('AwsIoTHttp2ProtocolGroup', 'Aws Io T Http2 Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIoTHttp2ProtocolGroup
include('aws-20210730/Resource/LoT/AwsIoTHttp2Protocol')

' renders the element
AwsIoTHttp2ProtocolGroup('AwsIoTHttp2ProtocolGroup', 'Aws Io T Http2 Protocol Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
